@@ -871,8 +871,7 @@ KScens.default <- function(times, cens = rep(1, length(times)),
                                           pnorm(2 * id * A * sr - kr)))
     if (all(sapply(params0, is.null))) {
       output <- list(Distribution = distr,
-                     Test = c(A = A, "p-value" = pval, "F(ym)" = R,
-                              ym = stimes[m]),
+                     Test = c(A = A, "p-value" = pval),
                      Estimates = c(shape = alphaML, shape2 = gammaML,
                                    location = muML, scale = betaML),
                      StdErrors = c(shapeSE = alphaSE, shape2SE = gammaSE,
@@ -882,8 +881,7 @@ KScens.default <- function(times, cens = rep(1, length(times)),
     } else {
       output <- list(Distribution = distr,
                      Hypothesis = hypo,
-                     Test = c(A = A, "p-value" = pval, "F(ym)" = R,
-                              ym = stimes[m]),
+                     Test = c(A = A, "p-value" = pval),
                      Estimates = c(shape = alphaML, shape2 = gammaML,
                                    location = muML, scale = betaML),
                      StdErrors = c(shapeSE = alphaSE, shape2SE = gammaSE,
